@@ -349,45 +349,67 @@ caja_drag_items_on_desktop (const GList *selection_list)
 GdkDragAction
 caja_drag_default_drop_action_for_netscape_url (GdkDragContext *context)
 {
-    /* Mozilla defaults to copy, but unless thats the
-       only allowed thing (enforced by ctrl) we want to ASK */
-    if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_COPY &&
-            gdk_drag_context_get_actions (context) != GDK_ACTION_COPY)
+    /* Mozilla defaults to copy, however by default caja creates a link
+     * if available.
+     *
+     * Enforced action X:
+     * ((actions & X) != 0) && (suggested_action == X)
+     *    - GDK_ACTION_LINK enforced by Alt
+     *    - GDK_ACTION_MOVE enforced by Shift
+     *    - GDK_ACTION_COPY enforced by Ctrl
+     */
+    GdkDragAction suggested_action = gdk_drag_context_get_suggested_action (context);
+    GdkDragAction actions = gdk_drag_context_get_actions (context);
+    if ((actions & GDK_ACTION_LINK) == GDK_ACTION_LINK)
     {
-        return GDK_ACTION_ASK;
+        return GDK_ACTION_LINK;
     }
-    else if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_MOVE)
+    else if (suggested_action == GDK_ACTION_MOVE)
     {
         /* Don't support move */
         return GDK_ACTION_COPY;
     }
 
-    return gdk_drag_context_get_suggested_action (context);
+    return suggested_action;
 }
 
 static gboolean
-check_same_fs (CajaFile *file1,
-               CajaFile *file2)
+check_same_fs (const char *target_uri, 
+               CajaFile *target_file,
+               const char *dropped_uri,
+               CajaFile *dropped_file)
 {
     gboolean result;
 
     result = FALSE;
 
-    if (file1 != NULL && file2 != NULL)
+    char *target_fs = NULL, *dropped_fs = NULL;
+
+    if (target_file != NULL)
     {
-        char *id1, *id2;
-
-        id1 = caja_file_get_filesystem_id (file1);
-        id2 = caja_file_get_filesystem_id (file2);
-
-        if (id1 != NULL && id2 != NULL)
-        {
-            result = (strcmp (id1, id2) == 0);
-        }
-
-        g_free (id1);
-        g_free (id2);
+        target_fs = caja_file_get_filesystem_id (target_file);
     }
+    if (target_fs == NULL)
+    {
+        target_fs = caja_get_filesystem_id_by_uri (target_uri, TRUE);
+    }
+
+    if (dropped_file != NULL && !caja_file_is_symbolic_link (dropped_file))
+    {
+        dropped_fs = caja_file_get_filesystem_id (dropped_file);
+    }
+    if (dropped_fs == NULL)
+    {
+        dropped_fs = caja_get_filesystem_id_by_uri (dropped_uri, FALSE);
+    }
+
+    if (target_fs != NULL && dropped_fs != NULL)
+    {
+        result = (strcmp (target_fs, dropped_fs) == 0);
+    }
+
+    g_free (target_fs);
+    g_free (dropped_fs);
 
     return result;
 }
@@ -511,7 +533,7 @@ caja_drag_default_drop_action_for_icons (GdkDragContext *context,
         target = g_file_new_for_uri (target_uri_string);
     }
 
-    same_fs = check_same_fs (target_file, dropped_file);
+    same_fs = check_same_fs (target_uri_string, target_file, dropped_uri, dropped_file);
 
     caja_file_unref (dropped_file);
     caja_file_unref (target_file);
