@@ -33,13 +33,14 @@
 
 #include <config.h>
 #include <math.h>
-#include "caja-icon-dnd.h"
+#include <stdio.h>
+#include <string.h>
+
+#include <gdk/gdkkeysyms.h>
+#include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
-#include "caja-debug-log.h"
-#include "caja-file-dnd.h"
-#include "caja-icon-private.h"
-#include "caja-link.h"
-#include "caja-metadata.h"
 #include <eel/eel-background.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
@@ -50,15 +51,16 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gdk/gdkkeysyms.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
 #include <eel/eel-canvas-rect-ellipse.h>
-#include <libcaja-private/caja-file-utilities.h>
-#include <libcaja-private/caja-file-changes-queue.h>
-#include <stdio.h>
-#include <string.h>
+
+#include "caja-icon-dnd.h"
+#include "caja-debug-log.h"
+#include "caja-file-dnd.h"
+#include "caja-icon-private.h"
+#include "caja-link.h"
+#include "caja-metadata.h"
+#include "caja-file-utilities.h"
+#include "caja-file-changes-queue.h"
 
 static const GtkTargetEntry drag_types [] =
 {
@@ -280,7 +282,7 @@ caja_icon_container_each_selected_icon (CajaIconContainer *container,
                                         gboolean (*each_function) (CajaIcon *, gpointer), gpointer data)
 {
     GList *p;
-    CajaIcon *icon;
+    CajaIcon *icon = NULL;
 
     for (p = container->details->icons; p != NULL; p = p->next)
     {
@@ -422,7 +424,6 @@ get_direct_save_filename (GdkDragContext *context)
 static void
 set_direct_save_uri (GtkWidget *widget, GdkDragContext *context, CajaDragInfo *drag_info, int x, int y)
 {
-    GFile *base, *child;
     char *filename, *drop_target;
     gchar *uri;
 
@@ -443,6 +444,8 @@ set_direct_save_uri (GtkWidget *widget, GdkDragContext *context, CajaDragInfo *d
 
     if (filename != NULL && drop_target != NULL)
     {
+        GFile *base, *child;
+
         /* Resolve relative path */
         base = g_file_new_for_uri (drop_target);
         child = g_file_get_child (base, filename);
@@ -853,7 +856,7 @@ auto_scroll_timeout_callback (gpointer data)
     container = CAJA_ICON_CONTAINER (widget);
 
     if (container->details->dnd_info->drag_info.waiting_to_autoscroll
-            && container->details->dnd_info->drag_info.start_auto_scroll_in > eel_get_system_time())
+            && container->details->dnd_info->drag_info.start_auto_scroll_in > g_get_monotonic_time())
     {
         /* not yet */
         return TRUE;
@@ -947,12 +950,12 @@ handle_local_move (CajaIconContainer *container,
                    double world_x, double world_y)
 {
     GList *moved_icons, *p;
-    CajaDragSelectionItem *item;
-    CajaIcon *icon;
     CajaFile *file;
     char screen_string[32];
     GdkScreen *screen;
     time_t now;
+    CajaDragSelectionItem *item = NULL;
+    CajaIcon *icon = NULL;
 
     if (container->details->auto_layout)
     {
@@ -1020,7 +1023,6 @@ handle_nonlocal_move (CajaIconContainer *container,
     GList *source_uris, *p;
     GArray *source_item_locations;
     gboolean free_target_uri, is_rtl;
-    int index, item_x;
     GtkAllocation allocation;
 
     if (container->details->dnd_info->drag_info.selection_list == NULL)
@@ -1041,6 +1043,8 @@ handle_nonlocal_move (CajaIconContainer *container,
     source_item_locations = g_array_new (FALSE, TRUE, sizeof (GdkPoint));
     if (!icon_hit)
     {
+        int index;
+
         /* Drop onto a container. Pass along the item points to allow placing
          * the items in their same relative positions in the new container.
          */
@@ -1050,6 +1054,8 @@ handle_nonlocal_move (CajaIconContainer *container,
         for (index = 0, p = container->details->dnd_info->drag_info.selection_list;
                 p != NULL; index++, p = p->next)
         {
+            int item_x;
+
             item_x = ((CajaDragSelectionItem *)p->data)->icon_x;
             if (is_rtl)
                 item_x = -item_x - ((CajaDragSelectionItem *)p->data)->icon_width;
@@ -1099,9 +1105,6 @@ caja_icon_container_find_drop_target (CajaIconContainer *container,
 {
     CajaIcon *drop_target_icon;
     double world_x, world_y;
-    CajaFile *file;
-    char *icon_uri;
-    char *container_uri;
 
     if (icon_hit)
     {
@@ -1125,9 +1128,13 @@ caja_icon_container_find_drop_target (CajaIconContainer *container,
     drop_target_icon = caja_icon_container_item_at (container, world_x, world_y);
     if (drop_target_icon != NULL)
     {
+        char *icon_uri;
+
         icon_uri = caja_icon_container_get_icon_uri (container, drop_target_icon);
         if (icon_uri != NULL)
         {
+            CajaFile *file;
+
             file = caja_file_get_by_uri (icon_uri);
 
             if (!caja_drag_can_accept_info (file,
@@ -1147,6 +1154,8 @@ caja_icon_container_find_drop_target (CajaIconContainer *container,
 
     if (drop_target_icon == NULL)
     {
+        char *container_uri;
+
         if (icon_hit)
         {
             *icon_hit = FALSE;
@@ -1223,7 +1232,6 @@ caja_icon_container_receive_dropped_icons (CajaIconContainer *container,
     double world_x, world_y;
     gboolean icon_hit;
     GdkDragAction action, real_action;
-    CajaDragSelectionItem *selected_item;
 
     drop_target = NULL;
 
@@ -1257,6 +1265,8 @@ caja_icon_container_receive_dropped_icons (CajaIconContainer *container,
 
     if (real_action == (GdkDragAction) CAJA_DND_ACTION_SET_AS_BACKGROUND)
     {
+        CajaDragSelectionItem *selected_item;
+
         selected_item = container->details->dnd_info->drag_info.selection_list->data;
         eel_background_set_dropped_image (eel_get_widget_background (GTK_WIDGET (container)),
                                           real_action, selected_item->uri);
@@ -1404,9 +1414,7 @@ caja_icon_dnd_update_drop_target (CajaIconContainer *container,
                                   int x, int y)
 {
     CajaIcon *icon;
-    CajaFile *file;
     double world_x, world_y;
-    char *uri;
 
     g_assert (CAJA_IS_ICON_CONTAINER (container));
 
@@ -1424,6 +1432,9 @@ caja_icon_dnd_update_drop_target (CajaIconContainer *container,
     /* Find if target icon accepts our drop. */
     if (icon != NULL && (container->details->dnd_info->drag_info.data_type != CAJA_ICON_DND_KEYWORD))
     {
+        CajaFile *file;
+        char *uri;
+
         uri = caja_icon_container_get_icon_uri (container, icon);
         file = caja_file_get_by_uri (uri);
         g_free (uri);
@@ -1749,10 +1760,6 @@ drag_data_received_callback (GtkWidget *widget,
                              gpointer user_data)
 {
     CajaDragInfo *drag_info;
-    EelBackground *background;
-    char *tmp;
-    const char *tmp_raw;
-    int length;
     gboolean success;
 
     drag_info = &(CAJA_ICON_CONTAINER (widget)->details->dnd_info->drag_info);
@@ -1799,6 +1806,10 @@ drag_data_received_callback (GtkWidget *widget,
      */
     if (drag_info->drop_occured)
     {
+        EelBackground *background;
+        char *tmp;
+        const char *tmp_raw;
+        int length;
 
         success = FALSE;
         switch (info)
