@@ -272,6 +272,12 @@ caja_window_go_up_signal (CajaWindow *window, gboolean close_behind)
     return TRUE;
 }
 
+static void
+caja_window_reload_signal (CajaWindow *window)
+{
+    caja_window_reload (window, FALSE);
+}
+
 void
 caja_window_new_tab (CajaWindow *window)
 {
@@ -320,7 +326,7 @@ caja_window_new_window (CajaWindow *window)
     current_slot = window->details->active_pane->active_slot;
     location = caja_window_slot_get_location (current_slot);
 
-    if (location != NULL) 
+    if (location != NULL)
     {
         CajaWindow *new_window;
         CajaWindowSlot *new_slot;
@@ -476,6 +482,28 @@ caja_window_sync_allow_stop (CajaWindow *window,
     }
 }
 
+void
+caja_window_reload (CajaWindow *window, gboolean new_tab)
+{
+    CajaWindowSlot *slot;
+
+    g_assert (CAJA_IS_WINDOW (window));
+
+    slot = window->details->active_pane->active_slot;
+
+    if (new_tab && slot->location != NULL)
+    {
+        caja_window_slot_open_location_full (slot, slot->location,
+                                             CAJA_WINDOW_OPEN_ACCORDING_TO_MODE,
+                                             CAJA_WINDOW_OPEN_FLAG_NEW_TAB,
+                                             NULL, NULL, NULL);
+    }
+    else
+    {
+        caja_window_slot_reload (slot);
+    }
+}
+
 void
 caja_window_allow_reload (CajaWindow *window, gboolean allow)
 {
@@ -1086,14 +1114,14 @@ caja_window_key_press_event (GtkWidget *widget,
  */
 
 static void
-free_activate_view_data (gpointer data)
+free_activate_view_data (gpointer  data,
+                         GClosure *closure)
 {
     ActivateViewData *activate_data;
+    (void) closure;
 
     activate_data = data;
-
     g_free (activate_data->id);
-
     g_slice_free (ActivateViewData, activate_data);
 }
 
@@ -1177,7 +1205,7 @@ add_view_as_menu_item (CajaWindow *window,
     data->id = g_strdup (identifier);
     g_signal_connect_data (action, "activate",
                            G_CALLBACK (action_view_as_callback),
-                           data, (GClosureNotify) free_activate_view_data, 0);
+                           data, free_activate_view_data, 0);
 
     G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_group_add_action (window->details->view_as_action_group,
@@ -1395,7 +1423,9 @@ load_view_as_menu (CajaWindow *window)
     window->details->short_list_merge_id = merge_id;
     G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     window->details->view_as_action_group = gtk_action_group_new ("ViewAsGroup");
+#ifdef ENABLE_NLS
     gtk_action_group_set_translation_domain (window->details->view_as_action_group, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
     G_GNUC_END_IGNORE_DEPRECATIONS;
     window->details->view_as_radio_action = NULL;
 
@@ -1495,12 +1525,8 @@ real_sync_title (CajaWindow *window,
 {
     if (slot == window->details->active_pane->active_slot)
     {
-        char *copy;
-
-        copy = g_strdup (slot->title);
         g_signal_emit_by_name (window, "title_changed",
                                slot->title);
-        g_free (copy);
     }
 }
 
@@ -1948,10 +1974,18 @@ caja_get_history_list (void)
     return history_list;
 }
 
+static gpointer
+caja_window_copy_history_item (gconstpointer src,
+                               gpointer      data)
+{
+    (void) data;
+    return g_object_ref (G_OBJECT (src));
+}
+
 static GList *
 caja_window_get_history (CajaWindow *window)
 {
-    return g_list_copy_deep (history_list, (GCopyFunc) g_object_ref, NULL);
+    return g_list_copy_deep (history_list, caja_window_copy_history_item, NULL);
 }
 
 
@@ -2220,6 +2254,6 @@ caja_window_class_init (CajaWindowClass *class)
                                   "prompt-for-location", 1,
                                   G_TYPE_STRING, "/");
 
-    class->reload = caja_window_reload;
+    class->reload = caja_window_reload_signal;
     class->go_up = caja_window_go_up_signal;
 }
